/*
ti pa

01.2       = sky

24.3       = branch: wire1 up, wire2 left, wire3 right
25.3       = horizontal wire3
26.3       = branch: wire3 left, wire2 right, wire1 down
27.3       = horizontal wire2
2B.3       = vertical wire1
2C.3       = vertical wire3
2D.3       = decoration, wants wire3 down, can take wires left
2E.3       = decoration, wants wire2 right, can take wires up
2F.3       = background

34.3       = background shadow
36.3 37.3
3E.3 3F.3 = background detail (inset)

60.0 {61.0} 62.0
68.0 {69.0} 6A.0 = wall

70.0         = singleblock platform
61.0         = longer platform
60.0         = platform left edge, if in air
62.0         = platform right edge, if in air


73.1         = arc generator

7C.1 7D.1   = arcbox (wall decoration)
72.0         = singletile wall decoration

75.0         = one type of vertical wall (or horizontal!)
71.0         = another type of vertical wall

83.0         = ladder

*/
static void ElecmanAscii(Screen& s)
{
    for(unsigned y=0; y<16; ++y)
        for(unsigned x=0; x<16; ++x)
        {
            unsigned char c = s.outmap[y*16+x].tile;
            char ch = '?';
            /* Classify types.
             *
             *
             *
             */
            switch(c)
            {
                // air:
                case 0x01:
                case 0x00: //void
                    ch = '.';
                    break;
                case 0x24 ... 0x27:
                case 0x2B ... 0x2F:
                case 0x34:
                case 0x36: case 0x37:
                case 0x3E: case 0x3F:
                    ch = ' ';
                    break;
                
                case 0x60 ... 0x62:
                case 0x68 ... 0x6A:
                case 0x70:
                case 0x72:
                case 0x71: case 0x75: // walls..
                case 0x51: case 0x52: case 0x53: // wily signature
                    ch = '#';
                    break;
                
                case 0x83:
                    ch = Ascii_Ladder;
                    break;
                
                case 0x10:
                    ch = Ascii_WilyDoor;
                    break;
                
                case 0x73:
                    ch = 'A'; // arc generator
                    break;
                
                case 0x7C: case 0x7D:
                    ch = '$';
                    break;

                case 0x38:
                case 0x39:
                case 0x3A:
                case 0x3B:
                    ch = Ascii_Guts;
                    break;

                // no spikes
            }
            
            s.ascii[y*32+x] = ch;
            s.ascii[y*32+x+16] = ' ';
            //printf("%02X",c);
        }
}

#define ElecmanChar  DummyChar

static Level Elecman =
{
	4, // level number
	"Elecman",

	// screens:
	{
		{
		"##           |##"   "                "
		"##           |##"   "                "
		"##           |##"   "                "
		"##           |##"   "                "
		"##        ######"   "                "
		"##            ##"   "  f             "
		"#######       ##"   "                "
		"##            ##"   "             f  "
		"##        ######"   "                "
		"##            ##"   "      f         "
		"#######       ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Up},
		{
		"## |          ##"   "                "
		"## |          ##"   "                "
		"## |          ##"   "                "
		"## |          ##"   "                "
		"## |          ##"   "                "
		"## ##         ##"   "             E  "
		"## ##       ####"   "                "
		"## ##         ##"   "     f          "
		"## ###A       ##"   "                "
		"##            ##"   "         f      "
		"##      #A    ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"###|#  ######|##"   "                "
		"###|#  ######|##"   "                "
		"###|#  ######|##"   "                "
		,Up},
		{
		"## |          ##"   "                "
		"## |          ##"   "                "
		"## |          ##"   "                "
		"## |          ##"   "                "
		"## |          ##"   "                "
		"## ##         ##"   "                "
		"## ##       ####"   "                "
		"## ##         ##"   "                "
		"## ###A       ##"   "         -      "
		"##            ##"   "                "
		"##      #A    ##"   "            =   "
		"##            ##"   "                "
		"##            ##"   "                "
		"###|#  ######|##"   "                "
		"###|#  ######|##"   "                "
		"###|#  ######|##"   "                "
		,Up},
		{
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"## |###|      ##"   "                "
		"## |###|      ##"   "                "
		"## |###|      ##"   "                "
		,Up},
		{
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"##     |      ##"   "                "
		"## |###|      ##"   "                "
		"## |###|      ##"   "                "
		"## |###|      ##"   "                "
		,Up},
		{
		"## |         |##"   "                "
		"## |         |##"   "                "
		"## |         |##"   "                "
		"## #         |##"   "                "
		"##           |##"   "                "
		"##           ###"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##       #    ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##     |##    ##"   "                "
		"##     |##    ##"   "                "
		"##     |##    ##"   "                "
		,Up},
		{
		"...|....########"   "                "
		"...|....########"   "                "
		"...|......######"   "                "
		"...|......##$$##"   "               "
		"...|......######"   "                "
		"...|......######"   "                "
		"#######|########"   "                "
		"##$$###|####$$##"   "               "
		"#######|  ######"   "                "
		"##$$###|  ######"   "                "
		"########      ##"   "                "
		"##            ##"   "                "
		"##           |##"   "     ppp        "
		"## |####     |##"   "                "
		"## |         |##"   "                "
		"## |         |##"   "                "
		,Up},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		".....###########"   "                "
		".....#$$####$$.."   "               "
		"...|##########.."   "               E"
		"...|##$$####$$##"   "               "
		"...|############"   "                "
		"...|############"   "                "
		,Right},
		{
		"............|..."   "                "
		"............|..."   "                "
		"............|..."   "                "
		"............|..."   "                "
		"................"   "                "
		"................"   "                "
		".............#.."   "                "
		"..........#....."   "                "
		"................"   "                "
		"................"   "                "
		"...........#...."   "                "
		"................"   "                "
		".........#......"   "                "
		"..#...#........."   "                "
		"................"   "                "
		"................"   "                "
		,Up},
		{
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"....|.##|     ##"   "                "
		"......        ##"   "                "
		"......        ##"   "                "
		"############|###"   "                "
		"############|###"   "                "
		"############|###"   "                "
		"############|###"   "                "
		,Up},
		{
		"...|....##  | ##"   "                "
		"...|....$$  | ##"   "                "
		"...|....##  | ##"   "                "
		"...|....##  | A#"   "  f         -   "
		"..##....##|#####"   "                "
		"........$$|#####"   "      f         "
		"......####|   ##"   "                "
		"........##|   A#"   "   f        =   "
		"..##....####| ##"   "                "
		"........$$##| ##"   "               "
		"......##    | ##"   "                "
		"......##    | ##"   "                "
		"..##|###|#######"   "                "
		"..##|###|#######"   "                "
		"..##|###|#######"   "                "
		"..##|###|#######"   "                "
		,Up},
		{
		"....|...##  | ##"   "                "
		"....|...##  | ##"   "                "
		"....|...##  | ##"   "                "
		"........$$  | ##"   "               "
		"........##  | ##"   "                "
		"........##  | ##"   "                "
		"......####    ##"   "                "
		"........$$    ##"   "                "
		"..##....GG    ##"   "                "
		"........GG    ##"   "                "
		"......######|###"   "                "
		"......##$$  | ##"   "               "
		"..#|######  | ##"   "                "
		"..#|######  | ##"   "                "
		"..#|######  | ##"   "                "
		"..#|######  | ##"   "                "
		,Up},
		{
		"...|........|.##"   "                "
		"...|........|.##"   "                "
		"...|........|.##"   "                "
		"...|........|.##"   "                "
		"......##########"   "                "
		"..##..##########"   "                "
		"......GGGGGG..##"   "                "
		"......GGGGGG..##"   "             M  "
		"..|#############"   "                "
		"..|#############"   "                "
		"..|...........##"   "                "
		"..|...........##"   "                "
		"..##|#######|###"   "                "
		"..##|#######|###"   "                "
		"..##|#######|###"   "                "
		"..##|#######|###"   "                "
		,Up},
		{
		"....|...##  | ##"   "                "
		"....|...##  | ##"   "                "
		"....|...##  | ##"   "                "
		"....|...$$  | ##"   "               "
		"..##|...##  | ##"   "                "
		"........##  | A#"   "      f     -   "
		"......####  | ##"   "                "
		"........$$  | ##"   "   f            "
		"..|###..GG  | ##"   "                "
		"..|.....GG  | A#"   "            =   "
		"..|.......##| ##"   "                "
		"..|.......##| ##"   "      f         "
		"###|..######|###"   "                "
		"###|########|###"   "                "
		"###|########|###"   "                "
		"###|########|###"   "                "
		,Up},
		{
		"..|..#####  | ##"   "                "
		"..|..#####  | ##"   "                "
		"..|..#####  | ##"   "                "
		"..|..###$$  | A#"   "            -   "
		"..|..#####  | ##"   "                "
		"..|..A####  | ##"   "   -            "
		"..|..##     | ##"   "                "
		"..|..##     | ##"   "                "
		"..|..##|########"   "                "
		"..|..A#|########"   "   =            "
		"..|..##|      ##"   "                "
		"..|..##|      ##"   "                "
		"..##|#######|###"   "                "
		"..##|#######|###"   "                "
		"..##|#######|###"   "                "
		"..##|#######|###"   "                "
		,Up},
		{
		"...|......######"   "                "
		"...|......######"   "                "
		"...|..........##"   "                "
		"...|..........##"   "                "
		"...|..######..##"   "                "
		"...|..######..##"   "             j  "
		"......##    GG##"   "                "
		"......A#    GG##"   "    -    j      "
		"..|#####|#######"   "                "
		"..|#####|#######"   "                "
		"..|...##|     ##"   "                "
		"..|...A#|     ##"   "    =           "
		"..|...######|###"   "                "
		"..|...######|###"   "                "
		"..|...######|###"   "                "
		"..|...######|###"   "                "
		,Up},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		".....###########"   "                "
		".....#$$####$$.."   "                "
		"...|##########.."   "                "
		"...|##$$####$$##"   "              "
		"...|############"   "                "
		"...|############"   "                "
		,Right},
		{
		"............|..."   "                "
		"............|..."   "                "
		"............|..."   "                "
		"............|..."   "                "
		"................"   "                "
		"................"   "                "
		".............#.."   "                "
		"..........#....."   "                "
		"................"   "                "
		"................"   "                "
		"...........#...."   "                "
		"................"   "                "
		".........#......"   "                "
		"..#...#........."   "                "
		"................"   "                "
		"................"   "                "
		,Up},
		{
		"..|#############"   "                "
		"..|#########$$##"   "                "
		"..|.......######"   "                "
		"..|.......##$$##"   "               "
		"..|.......######"   "                "
		"..|.......##$$##"   "               "
		"............####"   "                "
		"............$$##"   "                "
		"...A..........##"   "      -         "
		"..............##"   "                "
		".....A........##"   "        =       "
		"..............##"   "                "
		"..............##"   "                "
		"############|.##"   "                "
		"############|.##"   "                "
		"############|.##"   "                "
		,Up},
		{
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		".............###"   "                "
		"..............DD"   "              SS"
		"..............DD"   "              SS"
		"..............DD"   "           t  SS"
		"..............DD"   "              SS"
		"..........######"   "                "
		"..........##$$##"   "               "
		"..|#############"   "                "
		"..|#####$$##$$##"   "               "
		"..|#############"   "                "
		"..|#############"   "                "
		,Shutter},
		{
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"######  | ##...."   "                "
		"######  | ##...."   "                "
		"          ##...."   "X               "
		"          ##...."   "X               "
		"          ##...."   "X               "
		"          ##...."   "X               "
		"############...."   "                "
		"############...."   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		,Up},
		{
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | A#...."   "        -       "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | A#...."   "        =       "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | A#...."   "        -       "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		,Up},
		{
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | A#...."   "        -       "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | A#...."   "        =       "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | A#...."   "        -       "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		"....##  | ##...."   "                "
		,Up},
		{
		"################"   "                "
		"################"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"##GGGG         #"   "                "
		"##GGGG         #"   "                "
		"######  | ######"   "      XXXX      "
		"######  | ######"   "      XXXX      "
		"######  | ######"   "                "
		"######  | ######"   "                "
		,End},
	},

	// palette
	{
		15, 32, 39, 23, 
		15, 32, 39, 33, 
		15, 15, 15, 12, 
		15, 40, 24,  8, 

		15, 44, 17, 15, 
		15, 32, 56, 15, 
		15, 48, 42, 15, 
		15, 48, 38, 15, 

		15, 32, 39, 23, 
		15, 32, 39, 33, 
		15, 15, 15, 12, 
		15, 32, 16,  0, 
	},

	// actives
	{
		Active( 0, 5, 0x40,0x50, 0x50,0x60 ),
		Active( 0, 5, 0x60,0x70, 0x70,0x80 ),
		Active( 0, 5, 0x90,0x70, 0xA0,0x80 ),
		Active( 0, 5, 0xB0,0x50, 0xC0,0x60 ),
		Active( 0, 6, 0x90,0xC0, 0xA0,0xD0 ),
		Active( 0, 6, 0xA0,0xC0, 0xB0,0xD0 ),
		Active( 0, 6, 0xB0,0xC0, 0xC0,0xD0 ),
		Active( 0, 6, 0xC0,0xC0, 0xD0,0xD0 ),
	},

	// enemies
	{
		Enemy( 3, 0x10,0xFF, 0x6 ),
		Enemy( 4, 0x10,0xFF, 0x6 ),
		Enemy( 5, 0x10,0x80, 0x10 ),
		Enemy( 6, 0x10,0x80, 0x10 ),
		Enemy( 9, 0x10,0xFF, 0x6 ),
		Enemy( 11, 0x10,0xFF, 0x6 ),
	},

	ElecmanAscii, ElecmanChar
};


